Documentation
¶
Overview ¶
Package accountmanager is a package that manages validator accounts from multiple sources.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Refresher ¶ added in v1.0.0
type Refresher interface {
// Refresh refreshes the accounts from the remote source, and account validator state from
// the validators provider.
// This is a relatively expensive operation, so should not be run in the validating path.
Refresh(ctx context.Context)
}
Refresher refreshes account information from the remote source.
type ValidatingAccountsProvider ¶
type ValidatingAccountsProvider interface {
// ValidatingAccountsForEpoch obtains the validating accounts for a given epoch.
ValidatingAccountsForEpoch(ctx context.Context, epoch phase0.Epoch) (map[phase0.ValidatorIndex]e2wtypes.Account, error)
// ValidatingAccountsForEpochByIndex obtains the specified validating accounts for a given epoch.
ValidatingAccountsForEpochByIndex(ctx context.Context,
epoch phase0.Epoch,
indices []phase0.ValidatorIndex,
) (
map[phase0.ValidatorIndex]e2wtypes.Account,
error,
)
}
ValidatingAccountsProvider provides methods for validating accounts.
Click to show internal directories.
Click to hide internal directories.