multinode

package
v0.6.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 30, 2020 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Overview

Package multinode is a strategy that obtains beacon block proposals from multiple nodes and selects the best one based on its attestation load.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Parameter

type Parameter interface {
	// contains filtered or unexported methods
}

Parameter is the interface for service parameters.

func WithAggregateAttestationsSubmitters

func WithAggregateAttestationsSubmitters(submitters map[string]eth2client.AggregateAttestationsSubmitter) Parameter

WithAggregateAttestationsSubmitters sets the aggregate attestation submitters.

func WithAttestationSubmitters

func WithAttestationSubmitters(submitters map[string]eth2client.AttestationSubmitter) Parameter

WithAttestationSubmitters sets the attestation submitters.

func WithBeaconBlockSubmitters

func WithBeaconBlockSubmitters(submitters map[string]eth2client.BeaconBlockSubmitter) Parameter

WithBeaconBlockSubmitters sets the beacon block submitters.

func WithBeaconCommitteeSubscriptionsSubmitters

func WithBeaconCommitteeSubscriptionsSubmitters(submitters map[string]eth2client.BeaconCommitteeSubscriptionsSubmitter) Parameter

WithBeaconCommitteeSubscriptionsSubmitters sets the attestation submitters.

func WithLogLevel

func WithLogLevel(logLevel zerolog.Level) Parameter

WithLogLevel sets the log level for the module.

func WithProcessConcurrency

func WithProcessConcurrency(concurrency int64) Parameter

WithProcessConcurrency sets the concurrency for the service.

type Service

type Service struct {
	// contains filtered or unexported fields
}

Service is the provider for beacon block proposals.

func New

func New(ctx context.Context, params ...Parameter) (*Service, error)

New creates a new beacon block propsal strategy.

func (*Service) SubmitAggregateAttestations added in v0.6.1

func (s *Service) SubmitAggregateAttestations(ctx context.Context, aggregates []*spec.SignedAggregateAndProof) error

SubmitAggregateAttestations submits aggregate attestations.

func (*Service) SubmitAttestation

func (s *Service) SubmitAttestation(ctx context.Context, attestation *spec.Attestation) error

SubmitAttestation submits an attestation.

func (*Service) SubmitBeaconBlock

func (s *Service) SubmitBeaconBlock(ctx context.Context, block *spec.SignedBeaconBlock) error

SubmitBeaconBlock submits a beacon block.

func (*Service) SubmitBeaconCommitteeSubscriptions

func (s *Service) SubmitBeaconCommitteeSubscriptions(ctx context.Context, subscriptions []*submitter.BeaconCommitteeSubscription) error

SubmitBeaconCommitteeSubscriptions submits a batch of beacon committee subscriptions.

Jump to